{ PVCAM Demonstration Script.

  This script is similar to PVDEMO01.V except it first creates a
  list of all the cameras in the system and lets the user choose 
  which camera to open.

  The user then focusses the camera, acquires a full-frame image 
  and displays the result on the VWin desktop. }

const
  ChooseMsg = 'Choose a camera to open' ;

var
  Image ;         { Image variable }
  xSize, ySize ;  { Size of camera CCD }

  nCams ;         { Number of cameras in system }
  index ;         { Looping index } 
  CamList ;       { List of camera names }
  Camera ;	  { Camera name }

begin

{ Find number of cameras in system }
nCams := pvcGetTotalCameras ;

{ Loop over camera names creating a list suitable for the 
  SelectString function - all list entries must be separated
  by the ";" character }
CamList := Str( pvcGetCameraName(0),';' ) ;
for index := 1 to nCams-1 do
  CamList := Str( CamList,';',pvcGetCameraName(index) ) ;

{ Choose a camera }
SelectString( ChooseMsg,CamList,Camera ) ;

{ Open the camera }
pvcOpenCamera( Camera ) ;

{ Check for errors }
if pvcError then
  Halt( pvcErrorMsg( pvcErrorCode ) ) ;

{ Focus the camera - not recommended for "ImagePoint" cameras }
pvcFocus( Str( 'Please focus camera "',Camera,'"' ) ) ;

{ Get size of CCD }
pvcGetCCDSize( xSize,ySize ) ;

{ Set the exposure time, gain and mode }
pvcSetExpTime( 200 ) ;
pvcSetExpMode( pvc_ExpTimed ) ;
pvcSetGain( 1 ) ;

{ Capture a full-frame image with no binning }
Image := pvcCapture( 0,0,xSize-1,ySize-1 ) ;

{ Display the image on the desktop }
Show( Image,'pvcdemo02' ) ;

end